# Generated by Django 5.0 on 2024-05-20 12:31

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="BatonTheme",
            fields=[
                ("id", models.AutoField(primary_key=True, serialize=False, verbose_name="id")),
                ("name", models.CharField(max_length=255, verbose_name="name")),
                ("theme", models.TextField(verbose_name="theme")),
                ("active", models.BooleanField(default=False, verbose_name="active")),
            ],
            options={
                'verbose_name': 'admin theme',
                'verbose_name_plural': 'admin themes'
            }
        ),
    ]



import json
import time
import hmac
import base64
import hashlib
import requests
from decimal import Decimal
from django.urls import reverse
from django import template
from django.utils.html import escapejs
from django.conf import settings
from django.core.exceptions import ImproperlyConfigured
from django.utils.module_loading import import_string

from baton.models import BatonTheme

from ..config import get_config
from ..ai import AIModels

register = template.Library()

def get_ai_models(ai_config):
    if ai_config.get("MODELS"): # function hook
        fn = import_string(ai_config.get("MODELS"))
        models = fn()
        translations_model = models.get('TRANSLATIONS_MODEL', AIModels.BATON_GPT_4O_MINI)
        summarizations_model = models.get('SUMMARIZATIONS_MODEL', AIModels.BATON_GPT_4O_MINI)
        corrections_model = models.get('CORRECTIONS_MODEL', AIModels.BATON_GPT_4O_MINI)
        images_model = models.get('IMAGES_MODEL', AIModels.BATON_DALL_E_3)
        vision_model = models.get('VISION_MODEL', AIModels.BATON_GPT_4O_MINI)
    else: # config
        translations_model = ai_config.get('TRANSLATIONS_MODEL', AIModels.BATON_GPT_4O_MINI)
        summarizations_model = ai_config.get('SUMMARIZATIONS_MODEL', AIModels.BATON_GPT_4O_MINI)
        corrections_model = ai_config.get('CORRECTIONS_MODEL', AIModels.BATON_GPT_4O_MINI)
        images_model = ai_config.get('IMAGES_MODEL', AIModels.BATON_DALL_E_3)
        vision_model = ai_config.get('VISION_MODEL', AIModels.BATON_GPT_4O_MINI)

    return {
        'TRANSLATIONS_MODEL': translations_model,
        'SUMMARIZATIONS_MODEL': summarizations_model,
        'CORRECTIONS_MODEL': corrections_model,
        'IMAGES_MODEL': images_model,
        'VISION_MODEL': vision_model
    }

@register.simple_tag
def baton_config():
    # retrieve the default language
    default_language = None
    try:
        default_language = settings.MODELTRANSLATION_DEFAULT_LANGUAGE
    except AttributeError:
        default_language = settings.LANGUAGES[0][0]
    except:
        pass

    # retrieve other languages for translations
    other_languages = []
    try:
        other_languages = [l[0] for l in settings.LANGUAGES if l[0] != default_language]
    except:
        pass

    ai_config = get_config('AI') or {}
    ai_models = get_ai_models(ai_config)

    conf = {
        "api": {
            "app_list": reverse('baton-app-list-json'),
            "gravatar": reverse('baton-gravatar-json'),
        },
        "ai": {
            "translationsModel": ai_models.get('TRANSLATIONS_MODEL', AIModels.BATON_GPT_4O_MINI),
            "correctionsModel": ai_models.get('CORRECTIONS_MODEL', AIModels.BATON_GPT_4O_MINI),
            "summarizationsModel": ai_models.get('SUMMARIZATIONS_MODEL', AIModels.BATON_GPT_4O_MINI),
            "imagesModel": ai_models.get('IMAGES_MODEL', AIModels.BATON_DALL_E_3),
            "visionModel": ai_models.get('VISION_MODEL', AIModels.BATON_GPT_4O_MINI),
            "enableTranslations": ai_config.get('ENABLE_TRANSLATIONS', False) if (get_config('BATON_CLIENT_ID') and get_config('BATON_CLIENT_SECRET')) else False,
            "enableCorrections": ai_config.get('ENABLE_CORRECTIONS', False) if (get_config('BATON_CLIENT_ID') and get_config('BATON_CLIENT_SECRET')) else False,
            "correctionSelectors": ai_config.get('CORRECTION_SELECTORS', ["textarea", "input[type=text]:not(.vDateField):not([name=username]):not([name*=subject_location])"]),
            "translateApiUrl": reverse('baton-translate'),
            "summarizeApiUrl": reverse('baton-summarize'),
            "visionApiUrl": reverse('baton-vision'),
            "generateImageApiUrl": reverse('baton-generate-image'),
            "correctApiUrl": reverse('baton-correct'),
        },
        "confirmUnsavedChanges": get_config('CONFIRM_UNSAVED_CHANGES'),
        "showMultipartUploading": get_config('SHOW_MULTIPART_UPLOADING'),
        "enableImagesPreview": get_config('ENABLE_IMAGES_PREVIEW'),
        "changelistFiltersInModal": get_config('CHANGELIST_FILTERS_IN_MODAL'),
        "changelistFiltersAlwaysOpen": get_config('CHANGELIST_FILTERS_ALWAYS_OPEN'),
        "changelistFiltersForm": get_config('CHANGELIST_FILTERS_FORM'),
        "changeformFixedSubmitRow": get_config('CHANGEFORM_FIXED_SUBMIT_ROW'),
        "collapsableUserArea": get_config('COLLAPSABLE_USER_AREA'),
        "menuAlwaysCollapsed": get_config('MENU_ALWAYS_COLLAPSED'),
        "menuTitle": escapejs(get_config('MENU_TITLE')),
        "messagesToasts": get_config('MESSAGES_TOASTS'),
        "gravatarDefaultImg": get_config('GRAVATAR_DEFAULT_IMG'),
        "gravatarEnabled": get_config('GRAVATAR_ENABLED'),
        "loginSplash": get_config('LOGIN_SPLASH'),
        "searchField": get_config('SEARCH_FIELD'),
        "forceTheme": get_config('FORCE_THEME'),
        "defaultLanguage": default_language,
        "otherLanguages": other_languages,
    }

    if conf['ai']['translationsModel'] not in AIModels.text_models:
        raise ImproperlyConfigured('Unsupported AI translation model %s' % conf['ai']['translationsModel'])

    if conf['ai']['correctionsModel'] not in AIModels.text_models:
        raise ImproperlyConfigured('Unsupported AI correction model %s' % conf['ai']['correctionsModel'])

    if conf['ai']['summarizationsModel'] not in AIModels.text_models:
        raise ImproperlyConfigured('Unsupported AI summarization model %s' % conf['ai']['summarizationsModel'])

    if conf['ai']['imagesModel'] not in AIModels.image_models:
        raise ImproperlyConfigured('Unsupported AI image model %s' % conf['ai']['imagesModel'])

    return conf


@register.simple_tag
def baton_config_value(key):
    return get_config(key)


@register.inclusion_tag('baton/theme.html')
def baton_theme():
    try:
        theme = BatonTheme.objects.get(active=True)
    except:
        theme = None
    return {
        'theme': theme,
    }

@register.inclusion_tag('baton/footer.html', takes_context=True)
def footer(context):
    user = context['user']
    return {
        'user': user,
        'support_href': get_config('SUPPORT_HREF'),
        'site_title': get_config('SITE_TITLE'),
        'copyright': get_config('COPYRIGHT'),
        'powered_by': get_config('POWERED_BY'),
    }


@register.simple_tag(takes_context=True)
def call_model_admin_method(context, **kwargs):
    try:
        model_admin = kwargs.pop('model_admin')
        method = kwargs.pop('method')
        return getattr(model_admin, method)(context['request'], **kwargs)
    except Exception as e:
        return None


@register.filter
def to_json(python_dict):
    return json.dumps(python_dict)


@register.inclusion_tag('baton/ai_stats.html', takes_context=True)
def baton_ai_stats(context):
    user = context['user']

    # The API endpoint to communicate with
    url_post = "https://baton.sqrt64.it/api/v1/stats/"
    # url_post = "http://localhost:1323/api/v1/stats/"

    # A GET request to the API
    ts = str(int(time.time()))
    h = hmac.new(settings.BATON.get('BATON_CLIENT_SECRET').encode('utf-8'), ts.encode('utf-8'), hashlib.sha256)
    sig = base64.b64encode(h.digest()).decode()

    error = False
    errorMessage = None
    status_code = 200
    budget = 0
    translations = {}
    summarizations = {}
    corrections = {}
    vision = {}
    images = {}
    response_json = {}

    try:
        response = requests.get(url_post, headers={
            'X-Client-Id': settings.BATON.get('BATON_CLIENT_ID'),
            'X-Timestamp': ts,
            'X-Signature': sig,
        })

        status_code = response.status_code
        if status_code != 200:
            error = True
            try:
                errorMessage = response.json().get('message', None)
            except Exception as e:
                errorMessage = str(e)
        else:
            response_json = response.json()
            budget = round(Decimal(response_json.get('budget', 0.0)), 2)
            translations = response_json.get('translations', {})
            summarizations = response_json.get('summarizations', {})
            vision = response_json.get('vision', {})
            corrections = response_json.get('corrections', {})
            images = response_json.get('images', {})
    except Exception as e:
        errorMessage = str(e)
        error = True

    ai_config = get_config('AI')
    ai_models = get_ai_models(ai_config)

    return {
        'user': user,
        'error': error,
        'error_message': errorMessage,
        'status_code': status_code,
        'budget': budget,
        'translations': translations,
        'summarizations': summarizations,
        'corrections': corrections,
        'vision': vision,
        'images': images,
        'translations_model': ai_models.get('TRANSLATIONS_MODEL', AIModels.BATON_GPT_4O_MINI),
        'corrections_model': ai_models.get('CORRECTIONS_MODEL', AIModels.BATON_GPT_4O_MINI),
        'summarizations_model': ai_models.get('SUMMARIZATIONS_MODEL', AIModels.BATON_GPT_4O_MINI),
        'images_model': ai_models.get('IMAGES_MODEL', AIModels.BATON_DALL_E_3),
        'vision_model': ai_models.get('VISION_MODEL', AIModels.BATON_GPT_4O_MINI),
    }



from django.contrib import admin

from ..config import get_config


class BatonAdminSite(admin.AdminSite):
    site_header = get_config('SITE_HEADER')
    site_title = get_config('SITE_TITLE')
    index_title = get_config('INDEX_TITLE')
    index_template = 'admin/index.html'
    enable_nav_sidebar = False

    def __init__(self, *args, **kwargs):
        """ Registers all apps with BatonAdminSite """
        super(BatonAdminSite, self).__init__(*args, **kwargs)
        # copy registered actions
        self._actions = admin.site._actions
        self._registry.update(admin.site._registry)
        for model in admin.site._registry:
            self.unregister([model])
            self.register([model], type(admin.site._registry[model]))


site = BatonAdminSite()

# override otherwise in admindocs the default admin site is used showing
# the navbar
admin.site = site



# Generated by Django 5.1.3 on 2024-12-02 08:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("baton", "0001_initial"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="batontheme",
            options={
                "verbose_name": "admin theme",
                "verbose_name_plural": "admin themes",
            },
        ),
        migrations.AlterField(
            model_name="batontheme",
            name="active",
            field=models.BooleanField(default=False, verbose_name="active"),
        ),
        migrations.AlterField(
            model_name="batontheme",
            name="id",
            field=models.AutoField(
                primary_key=True, serialize=False, verbose_name="id"
            ),
        ),
        migrations.AlterField(
            model_name="batontheme",
            name="name",
            field=models.CharField(max_length=255, verbose_name="name"),
        ),
        migrations.AlterField(
            model_name="batontheme",
            name="theme",
            field=models.TextField(verbose_name="theme"),
        ),
    ]



class AIModels:
    BATON_GPT_3_5_TURBO = "gpt-3.5-turbo"
    BATON_GPT_4_TURBO = 'gpt-4-turbo'
    BATON_GPT_4O = 'gpt-4o'
    BATON_GPT_4O_MINI = 'gpt-4o-mini'
    BATON_DALL_E_3 = 'dall-e-3'

    text_models = [
        BATON_GPT_3_5_TURBO,
        BATON_GPT_4_TURBO,
        BATON_GPT_4O,
        BATON_GPT_4O_MINI,
    ]
    image_models = [
        BATON_DALL_E_3,
    ]
    vision_models = [
        BATON_GPT_4O_MINI,
    ]



# -*- coding: utf-8 -*-
from django.conf import settings
from django.utils.html import mark_safe
from django.utils.translation import gettext as _

default_config = {
    "SITE_TITLE": "Baton",
    "SITE_HEADER": '<img class="baton-logo-light" src="%sbaton/img/logo.png" /><img class="baton-logo-dark" src="%sbaton/img/logo_dark.png" />'
    % (settings.STATIC_URL, settings.STATIC_URL),
    "INDEX_TITLE": _("Site administration"),
    "MENU_TITLE": _("Menu"),
    "SUPPORT_HREF": "https://github.com/otto-torino/django-baton/issues",
    "COPYRIGHT": 'copyright © 2022 <a href="https://www.otto.to.it">Otto srl</a>',  # noqa
    "POWERED_BY": '<a href="https://www.otto.to.it">Otto srl</a>',
    "IMAGE_PREVIEW_WIDTH": 200,
    "CONFIRM_UNSAVED_CHANGES": True,
    "SHOW_MULTIPART_UPLOADING": True,
    "ENABLE_IMAGES_PREVIEW": True,
    "COLLAPSABLE_USER_AREA": False,
    "CHANGELIST_FILTERS_IN_MODAL": True,
    "CHANGELIST_FILTERS_ALWAYS_OPEN": False,
    "CHANGELIST_FILTERS_FORM": False,
    "CHANGEFORM_FIXED_SUBMIT_ROW": True,
    "MENU_ALWAYS_COLLAPSED": False,
    "MESSAGES_TOASTS": False,
    "GRAVATAR_DEFAULT_IMG": "retro",
    "GRAVATAR_ENABLED": True,
    "LOGIN_SPLASH": None,
    "SEARCH_FIELD": None,
    "FORCE_THEME": None,
    "BATON_CLIENT_ID": None,
    "BATON_CLIENT_SECRET": None,
    "AI": None,
}


def get_config(key):
    safe = [
        "SITE_HEADER",
        "COPYRIGHT",
        "POWERED_BY",
    ]
    user_settings = getattr(settings, "BATON", None)

    if user_settings is None:
        value = default_config.get(key, None)
    else:
        value = user_settings.get(key, default_config.get(key, None))

    if key in safe:
        return mark_safe(value)

    return value



from django.db import models

from django.db.models.fields.files import ImageFieldFile
from django.utils.translation import gettext_lazy as _
from django.conf import settings
from django.utils.translation import get_language

from .forms import BatonAiImageFormField
from .widgets import BatonAiImageInput

class BatonAiImageFieldFile(ImageFieldFile):
    @property
    def subject_perc_position(self):
        if self.field.subject_location_field and getattr(
                self.instance, self.field.subject_location_field):
            (cX, cY) = getattr(self.instance,
                               self.field.subject_location_field).split(',')

            return {
                'x': int(cX),
                'y': int(cY)
            }
        return None

    @property
    def subject_position(self):
        perc = self.subject_perc_position
        if perc:
            return {
                'x': (self.width or 0) * perc.get('x', 0) // 100,
                'y': (self.height or 0) * perc.get('y', 0) // 100
            }
        return None

    @property
    def sorl(self):
        """ shortcut property to use with sorl-thumbnmail crop featur e"""
        position = self.subject_perc_position
        if position:
            x = position.get('x')
            y = position.get('y')
            # also need -0
            return '%s%% %s%%' % (x, y)
        return '50% 50%'

class BatonAiImageField(models.ImageField):
    attr_class = BatonAiImageFieldFile

    def __init__(self,
                 verbose_name=None,
                 name=None,
                 width_field=None,
                 height_field=None,
                 subject_location_field=None,
                 alt_field=None,
                 alt_chars=20,
                 alt_language=get_language(),
                 **kwargs):
        self.width_field, self.height_field = width_field, height_field
        self.subject_location_field = subject_location_field
        self.alt_field = alt_field
        self.alt_chars = alt_chars
        self.alt_language = alt_language
        super().__init__(verbose_name, name, **kwargs)

    def deconstruct(self):
        name, path, args, kwargs = super().deconstruct()
        if self.alt_field:
            kwargs['alt_field'] = self.alt_field
            kwargs['alt_chars'] = self.alt_chars
            kwargs['alt_language'] = self.alt_language
        if self.subject_location_field:
            kwargs['subject_location_field'] = self.subject_location_field
        return name, path, args, kwargs

    def formfield(self, **kwargs):
        d = kwargs
        # override widget
        d.update({
            'widget': BatonAiImageInput,
            'form_class': BatonAiImageFormField,
            'alt_field': self.alt_field,
            'alt_chars': self.alt_chars,
            'alt_language': self.alt_language,
            'subject_location_field': self.subject_location_field,
            'help_text':_('Drag the circle or click on the image to set the image subject') if self.subject_location_field else d.get('help_text', ''),
        })
        return super().formfield(**d)



from django.urls import path

from .views import (
    GetAppListJsonView,
    GetGravatartUrlJsonView,
    SummarizeView,
    VisionView,
    TranslateView,
    GenerateImageView,
    CorrectView,
)

urlpatterns = [
    path("app-list-json/", GetAppListJsonView.as_view(), name="baton-app-list-json"),
    path("gravatar/", GetGravatartUrlJsonView.as_view(), name="baton-gravatar-json"),
    path("translate/", TranslateView.as_view(), name="baton-translate"),
    path("summarize/", SummarizeView.as_view(), name="baton-summarize"),
    path("vision/", VisionView.as_view(), name="baton-vision"),
    path("generate-image/", GenerateImageView.as_view(), name="baton-generate-image"),
    path("correct/", CorrectView.as_view(), name="baton-correct"),
]



from django.forms.fields import ImageField
from .widgets import BatonAiImageInput
from .config import get_config


class BatonAiImageFormField(ImageField):
    widget = BatonAiImageInput

    def __init__(self, subject_location_field=None, alt_field=None, alt_chars=20, alt_language='en', *args, **kwargs):
        self.subject_location_field = subject_location_field
        self.alt_field = alt_field
        self.alt_chars = alt_chars
        self.alt_language = alt_language
        return super().__init__(*args, **kwargs)

    def widget_attrs(self, widget):
        attrs = super().widget_attrs(widget)
        attrs['subject_location_field'] = self.subject_location_field
        attrs['alt_field'] = self.alt_field
        attrs['alt_chars'] = self.alt_chars
        attrs['alt_language'] = self.alt_language
        attrs['preview_width'] = get_config('IMAGE_PREVIEW_WIDTH')
        return attrs



from django.db import models
from django.utils.translation import gettext_lazy as _

class BatonTheme(models.Model):
    id = models.AutoField(primary_key=True, verbose_name=_("id"))
    name = models.CharField(_("name"), max_length=255)
    theme = models.TextField(_("theme"))
    active = models.BooleanField(_("active"), default=False)

    def __str__(self):
        return self.name

    # override save, only one theme can be active
    def save(self, *args, **kwargs):
        if self.active:
            self.__class__.objects.exclude(pk=self.pk).update(active=False)
        super(BatonTheme, self).save(*args, **kwargs)

    class Meta:
        verbose_name = _("admin theme")
        verbose_name_plural = _("admin themes")



import os
from setuptools import setup

with open(os.path.join(os.path.dirname(__file__), "README.md")) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

REPO_URL = "http://github.com/otto-torino/django-baton"

setup(
    name="django-baton",
    version="5.0.6",
    packages=["baton", "baton.autodiscover", "baton.templatetags"],
    include_package_data=True,
    license="MIT License",
    description="A cool, modern and responsive django admin application",
    long_description=README,
    long_description_content_type="text/markdown",
    url=REPO_URL,
    author="abidibo",
    author_email="abidibo@gmail.com",
    install_requires=[
        "requests",
    ],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Web Environment",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "Intended Audience :: System Administrators",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Framework :: Django :: 2.1",
        "Framework :: Django :: 2.2",
        "Framework :: Django :: 3.0",
        "Framework :: Django :: 3.1",
        "Framework :: Django :: 4.0",
        "Framework :: Django :: 4.1",
        "Framework :: Django :: 4.2",
        "Framework :: Django :: 5.0",
        "Topic :: Software Development",
        "Topic :: Software Development :: User Interfaces",
    ],
    project_urls={
        "Documentation": "https://django-baton.readthedocs.io/en/latest/",
        "Demo": "https://django-baton.sqrt64.it/admin",
        "Source": REPO_URL,
        "Tracker": REPO_URL + "/issues",
    },
)
